@@ -327,6 +327,43 @@ int artnet_read(artnet_node vn, int timeout) {
   return ARTNET_EOK;
 }
 
+int artnet_read_one(artnet_node vn)
+{
+  node n = (node)vn;
+  node tmp;
+  artnet_packet_t p;
+  int ret;
+
+  check_nullnode(vn);
+
+  if(n->state.mode != ARTNET_ON)
+    return ARTNET_EACTION;
+
+  {
+    memset(&p.data, 0x0, sizeof(p.data));
+
+    if((ret = artnet_net_recv_read(n, &p)) < 0)
+      return ret;
+
+    // nothing to read
+    if(ret == RECV_NO_DATA)
+      return ARTNET_EOK;
+
+    // skip this packet (filtered)
+    if(p.length == 0)
+      return ARTNET_EOK;
+
+    if(p.length > MIN_PACKET_SIZE && get_type(&p))
+    {
+      handle(n, &p);
+      for(tmp = n->peering.peer; tmp != NULL && tmp != n; tmp = tmp->peering.peer)
+      {
+        handle(tmp, &p);
+      }
+    }
+  }
+  return ARTNET_EOK;
+}
 
 /*
  * To get around the 4 universes per node limitation , we can start more than
