@@ -10,6 +10,7 @@ class QStackedLayout;
 class QLineEdit;
 class QSpinBox;
 class QWidget;
+class QFormLayout;
 
 namespace Protocols
 {
@@ -23,10 +24,44 @@ class WebsocketClientWidget;
 class WebsocketServerWidget;
 
 class RateWidget;
+
+enum class OscProtocol
+{
+  UDP = 0,
+  TCP = 1,
+  Serial = 2,
+  UnixDatagram = 3,
+  UnixStream = 4,
+  WSClient = 5,
+  WSServer = 6
+};
+
+class OSCTransportWidget : public QWidget
+{
+public:
+  explicit OSCTransportWidget(
+      Device::ProtocolSettingsWidget& proto, QWidget* parent = nullptr);
+
+  void setCurrentProtocol(OscProtocol index);
+  ossia::net::osc_protocol_configuration configuration(OscProtocol index) const noexcept;
+  OscProtocol setConfiguration(const ossia::net::osc_protocol_configuration& conf);
+
+private:
+  QStackedLayout* m_transportLayout{};
+
+  UDPWidget* m_udp{};
+  TCPWidget* m_tcp{};
+  SerialWidget* m_serial{};
+  UnixDatagramWidget* m_unix_dgram{};
+  UnixStreamWidget* m_unix_stream{};
+  WebsocketClientWidget* m_ws_client{};
+  WebsocketServerWidget* m_ws_server{};
+};
+
 class OSCProtocolSettingsWidget final : public Device::ProtocolSettingsWidget
 {
 public:
-  OSCProtocolSettingsWidget(QWidget* parent = nullptr);
+  explicit OSCProtocolSettingsWidget(QWidget* parent = nullptr);
 
   Device::DeviceSettings getSettings() const override;
   Device::Node getDevice() const override;
@@ -41,16 +76,7 @@ private:
   QCheckBox* m_bonjour{};
   QComboBox* m_transport{};
   QComboBox* m_oscVersion{};
-  QStackedLayout* m_transportLayout{};
-
-  UDPWidget* m_udp{};
-  TCPWidget* m_tcp{};
-  SerialWidget* m_serial{};
-  UnixDatagramWidget* m_unix_dgram{};
-  UnixStreamWidget* m_unix_stream{};
-  WebsocketClientWidget* m_ws_client{};
-  WebsocketServerWidget* m_ws_server{};
-
+  OSCTransportWidget* m_transportWidget{};
   OSCSpecificSettings m_settings;
 };
 }
